@@ -1,15 +1,20 @@
 #' Download PDO Index Data
 #'
-#' Downloads PDO index data from
+#' Downloads PDO index data from the no longer updated
 #' <http://research.jisao.washington.edu/pdo/PDO.latest>.
 #'
-#' `download_pdo()` is an alias for `pdo_download()`.
+#' \lifecycle{soft-deprecated}
 #'
-#' For more information see <https://github.com/poissonconsulting/rpdo>.
+#' Deprecated for [rsoi::download_pdo()].
+#'
+#' `download_pdo()` is an alias for `pdo_download()`.
 #'
 #' @return A data frame of the PDO index data.
 #' @export
 pdo_download <- function() {
+  lifecycle::deprecate_warn(
+    "0.3.1", "pdo_download()", "rsoi::download_pdo()", id = "pdo_download")
+
   pdo <- get_pdo()
   pdo <- clean_pdo(pdo)
   pdo <- read_pdo(pdo)
@@ -20,5 +25,8 @@ pdo_download <- function() {
 #' @rdname pdo_download
 #' @export
 download_pdo <- function() {
+  lifecycle::deprecate_warn(
+    "0.3.1", "pdo_download()", "rsoi::download_pdo()", id = "pdo_download")
+
   pdo_download()
 }
